#
# spec file for package python-rollbar
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python2
Name:           python-rollbar
Version:        0.16.3
Release:        1.5
Summary:        Report exceptions, errors, and log messages to Rollbar
License:        MIT
URL:            https://github.com/rollbar/pyrollbar
Source:         https://github.com/rollbar/pyrollbar/archive/v%{version}.tar.gz
# https://github.com/rollbar/pyrollbar/pull/340
Patch0:         python-rollbar-no-unittest2.patch
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module blinker}
BuildRequires:  %{python_module httpx}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 0.12.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.14.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 0.12.1
Requires:       python-setuptools
Requires:       python-six >= 1.14.0
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python2-enum34
BuildRequires:  python2-mock
BuildRequires:  python2-unittest2
%endif
%python_subpackages

%description
Send messages and exceptions with arbitrary context, get back aggregates, and debug production issues quickly.

%prep
%autosetup -p1 -n pyrollbar-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/rollbar
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not (test_shorten_array or test_encode_empty_tuple)'

%post
%python_install_alternative rollbar

%postun
%python_uninstall_alternative rollbar

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/rollbar
%{python_sitelib}/rollbar
%{python_sitelib}/rollbar-%{version}*-info

%changelog
* Mon Feb 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.16.3:
  * Pinned Python 2 CI tests to legacy version of dependencies. See #408
  * Add PyPI badge for supported Python versions. See #408
  * Add Django 4.0+ compatibility. See #408
  * Update PR template. See #408
  * SC-95272: Remove support for Python 3.3. See #408
- Disable broken tests in python 3.11, test_encode_empty_tuple
* Mon Jan 24 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.16.2:
  * Fix building person data in Django. See #385
  * Fix circular error logging for non-HTTP events in Starlette. See #390
  * Fix Python 3.4 builds. See #389
  * Add support for FastAPI framework. See #373
  * Add support for Starlette framework. See #373
  * Add support for ASGI-compliant frameworks. See #373
  * Add support for HTTPX async handler. See #373
  * Add new honored values of rollbar.SETTINGS['handler']: default, async
    and httpx. See #373
  * Add support for async report_exc_info and report_message. See #373
  * Collect user IP from X-Forwarded-For, fall back to X-Real-Ip. See #370
  * Improve examples. See #368
  * Fix Python 3.3 builds. See #374
  * Fix Flask 0.x builds. See #376
- Add httpx to BuildRequires
- Refresh python-rollbar-no-unittest2.patch
* Wed Aug  5 2020 Matej Cepl <mcepl@suse.com>
- Replace self.assertRegex with six.assertRegex in
  python-rollbar-no-unittest2.patch to finally unrequire
  unittest2 (gh#rollbar/pyrollbar#340).
- Update the patch according to the pending pull request
  gh#rollbar/pyrollbar#346.
* Sat Jul 18 2020 Matej Cepl <mcepl@suse.com>
- Upstream doesn't care about unittest2 at all
  (gh#rollbar/pyrollbar#340), we can just ignore it. Adjust
  python-rollbar-no-unittest2.patch accordingly.
* Wed Jun  3 2020 pgajdos@suse.com
- use %%pytest macro
- remove dependency on unittest2 for python3
- added patches
  https://github.com/rollbar/pyrollbar/pull/340
  + python-rollbar-no-unittest2.patch
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.15.0
  * Prevent recursive re-raising
  * Correctly apply logger formatting
  * Fix deprecation warnings
* Tue Mar 26 2019 pgajdos@suse.com
- require python-setuptools
* Mon Mar 25 2019 pgajdos@suse.com
- version update to 0.14.7
  * Create the configuration options, `capture_username`
    and `capture_email`.
  * Create the configuration option `capture_ip`.
  * Fix `request.files_keys` for Flask
  * If you call `init` multiple times we will update the settings
    at each call.
  * see CHANGELOG.md for details
* Wed Dec 13 2017 tchvatal@suse.com
- Add python-rpm-macros to buildrequires
* Wed Dec 13 2017 tchvatal@suse.com
- Switch to github url to contain license
- Distribute license
- Switch to singlespec
- Enable tests
- Add all missing test and runtime dependencies
* Mon Dec  4 2017 tampakrap@opensuse.org
- Initial package
